@@ -8,7 +8,7 @@ from html import escape, unescape
 import http.client
 from http.cookies import SimpleCookie
 from cgi import FieldStorage
-from omnitools import dt2yyyymmddhhmmss
+from omnitools import dt2yyyymmddhhmmss, HeadersDict
 
 
 default_log_file = "log.log"
@@ -21,10 +21,10 @@ arguments = FieldStorage(environ=os.environ)
 arguments = {k: [_.value for _ in arguments[k]] if isinstance(arguments[k], list) else arguments[k].value for k in arguments}
 _GET = arguments
 _POST = arguments
-_SESSION = SimpleCookie(_SERVER["HTTP_COOKIE"]) if "HTTP_COOKIE" in _SERVER else SimpleCookie()
-_COOKIE = {k: v.value for k, v in _SESSION.items()}
+_SESSION = SimpleCookie()
+_COOKIE = {k: v.value for k, v in SimpleCookie(_SERVER["HTTP_COOKIE"]).items()} if "HTTP_COOKIE" in _SERVER else {}
 # need to vet it manually as it depends on the system
-_HEADERS = {k: v for k, v in _SERVER.items() if k not in [
+_HEADERS = HeadersDict({k: v for k, v in _SERVER.items() if k not in [
     "DOCUMENT_ROOT",
     "LANG",
     "CONTEXT_DOCUMENT_ROOT",
@@ -46,7 +46,7 @@ _HEADERS = {k: v for k, v in _SERVER.items() if k not in [
     "SCRIPT_FILENAME",
     "PATH",
     "CONTEXT_PREFIX",
-]}
+]})
 default_content_type = {
     "Content-Type": "text/html; charset=utf-8"
 }
